==> acf-quagga-0.5.0.tar.bz2: acf-quagga-0.5.0/bgp-model.lua <==
module(..., package.seeall)

-- Load libraries
require("modelfunctions")
require("format")

-- Set variables
local path="PATH=/usr/local/bin:/usr/bin:/bin:/usr/local/sbin:/usr/sbin:/sbin "

local configfile = "/etc/quagga/bgpd.conf"
local processname = "bgpd"
local packagename = "quagga"

-- ################################################################################
-- LOCAL FUNCTIONS
local function parseconfigfile()
	local conf = {}
	local f = io.open(configfile, "r")
	local line, key, _, k, v
	
	if not f then
		return nil
	end

	for line in f:lines() do
		line = string.gsub(line, "%s*#.*", "")
		local k,v = string.match(line, "^%s*(%S*)%s+(.*)")
		if k then
			conf[k] = v
		end
	end
	f:close()
	return conf
end

local function telnetshowipbgp()
	local output = {}
	local configfile = parseconfigfile() or {}
	local cmd = path .. "echo -e '" .. format.escapespecialcharacters(configfile.password) .. "\nshow ip bgp\nquit\n' | nc localhost bgpd 2>/dev/null"
	local f = io.popen( cmd )
	local result = f:read("*a") or ""
	f:close()
	if result == "" then
		result = "Failed to find routes"
	end
	local startout, stopout
	for line in string.gmatch(result, "([^\n]*)\n?") do
		table.insert(output,line)
		if (string.find(line, "^Password:")) then
			startout = #output+1
		elseif (string.find(line, "^BGP")) then
			startout = #output
		elseif (string.find(line, "^Total number")) then
			stopout = #output
		end
	end
	return table.concat(output,"\n",startout,stopout)
end

-- ################################################################################
-- PUBLIC FUNCTIONS

function getstatus()
	return modelfunctions.getstatus(processname, packagename, "BGP Status")
end

function getconfigfile()
	return modelfunctions.getfiledetails(configfile)
end

function setconfigfile(filedetails)
	return modelfunctions.setfiledetails(filedetails, {configfile})
end

function startstop_service(action)
	return modelfunctions.startstop_service(processname, action)
end

function getdetails()
	local status = {}
	status.showipbgp = cfe({ label="BGP routes" })
	status.showipbgp.value = telnetshowipbgp()
	return cfe({ type="group", value=status, label="BGP Details" })
end

==> acf-quagga-0.7.0.tar.bz2: acf-quagga-0.7.0/bgp-model.lua <==
module(..., package.seeall)

-- Load libraries
require("modelfunctions")
format = require("acf.format")

-- Set variables
local path="PATH=/usr/local/bin:/usr/bin:/bin:/usr/local/sbin:/usr/sbin:/sbin "

local configfile = "/etc/quagga/bgpd.conf"
local processname = "bgpd"
local packagename = "quagga"

-- ################################################################################
-- LOCAL FUNCTIONS
local function parseconfigfile()
	local conf = {}
	local f = io.open(configfile, "r")
	local line, key, _, k, v
	
	if not f then
		return nil
	end

	for line in f:lines() do
		line = string.gsub(line, "%s*#.*", "")
		local k,v = string.match(line, "^%s*(%S*)%s+(.*)")
		if k then
			conf[k] = v
		end
	end
	f:close()
	return conf
end

local function telnetshowipbgp()
	local output = {}
	local configfile = parseconfigfile() or {}
	local cmd = path .. "echo -e '" .. format.escapespecialcharacters(configfile.password) .. "\nshow ip bgp\nquit\n' | nc localhost bgpd 2>/dev/null"
	local f = io.popen( cmd )
	local result = f:read("*a") or ""
	f:close()
	if result == "" then
		result = "Failed to find routes"
	end
	local startout, stopout
	for line in string.gmatch(result, "([^\n]*)\n?") do
		table.insert(output,line)
		if (string.find(line, "^Password:")) then
			startout = #output+1
		elseif (string.find(line, "^BGP")) then
			startout = #output
		elseif (string.find(line, "^Total number")) then
			stopout = #output
		end
	end
	return table.concat(output,"\n",startout,stopout)
end

-- ################################################################################
-- PUBLIC FUNCTIONS

function getstatus()
	return modelfunctions.getstatus(processname, packagename, "BGP Status")
end

function getconfigfile()
	return modelfunctions.getfiledetails(configfile)
end

function setconfigfile(self, filedetails)
	return modelfunctions.setfiledetails(self, filedetails, {configfile})
end

function get_startstop(self, clientdata)       
        return modelfunctions.get_startstop(processname)
end

function startstop_service(self, startstop, action)        
        return modelfunctions.startstop_service(startstop, action)
end

function getdetails()
	local status = {}
	status.showipbgp = cfe({ label="BGP routes" })
	status.showipbgp.value = telnetshowipbgp()
	return cfe({ type="group", value=status, label="BGP Details" })
end
